@@ -46,8 +46,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--mandir=/usr/share/man' '--infodir=/usr/share/info' "
                 "'--datadir=/usr/share' '--sysconfdir=/etc' "
                 "'--localstatedir=/var/lib' '--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.11.8_p1' "
-                "'--htmldir=/usr/share/doc/python-3.11.8_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.11.9-r1' "
+                "'--htmldir=/usr/share/doc/python-3.11.9-r1/html' "
                 "'--libdir=/usr/lib32' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -55,7 +55,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--without-lto' '--with-system-expat' '--with-system-ffi' "
-                "'--with-platlibdir=lib' '--with-pkg-config=yes' "
+                "'--with-system-libmpdec' '--with-platlibdir=lib' "
+                "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
@@ -66,16 +67,16 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'CXX': 'mips64el-unknown-linux-gnuabin32-g++',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
- 'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
+ 'DECIMAL_LDFLAGS': '-lmpdec',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
@@ -644,10 +645,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBFFI_INCLUDEDIR': '/usr/lib32/libffi/include',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-Wsign-compare -DNDEBUG -O2 -march=mips3 -mplt '
-                    '-Wa,-mfix-loongson2f-nop -mfix-r5900 -pipe -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -Wsign-compare -DNDEBUG -O2 '
+                    '-march=mips3 -mplt -Wa,-mfix-loongson2f-nop -mfix-r5900 '
+                    '-pipe -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -801,11 +801,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
-                           '-DANSI=1',
- 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
-                         'Modules/_decimal/libmpdec/libmpdec.a',
- 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
@@ -995,7 +993,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'mips64el-unknown-linux-gnuabin32-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1039,10 +1037,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1073,8 +1071,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.9-r1/work/Python-3.11.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
